@@ -24,7 +24,7 @@
   (See COPYING.txt)
 
   Last updated: July 8, 2008
-  $Id: rainbow.c,v 1.12 2008/07/10 20:26:40 wkendrick Exp $
+  $Id: rainbow.c,v 1.13 2011/12/19 09:32:26 perepujal Exp $
 */
 
 #include <stdio.h>
@@ -67,6 +67,40 @@ static int rainbow_color;
 static Uint32 rainbow_rgb;
 static Mix_Chunk * rainbow_snd;
 
+int rainbow_init(magic_api * api);
+Uint32 rainbow_api_version(void);
+int rainbow_get_tool_count(magic_api * api);
+SDL_Surface * rainbow_get_icon(magic_api * api, int which);
+char * rainbow_get_name(magic_api * api, int which);
+char * rainbow_get_description(magic_api * api, int which, int mode);
+static void rainbow_linecb(void * ptr, int which,
+		    SDL_Surface * canvas, SDL_Surface * last,
+                    int x, int y);
+
+void rainbow_drag(magic_api * api, int which, SDL_Surface * canvas,
+	          SDL_Surface * last, int ox, int oy, int x, int y,
+		  SDL_Rect * update_rect);
+
+void rainbow_click(magic_api * api, int which, int mode,
+	           SDL_Surface * canvas, SDL_Surface * last,
+	           int x, int y,
+		   SDL_Rect * update_rect);
+
+void rainbow_release(magic_api * api, int which,
+	           SDL_Surface * canvas, SDL_Surface * last,
+	           int x, int y,
+		   SDL_Rect * update_rect);
+
+
+void rainbow_shutdown(magic_api * api);
+void rainbow_set_color(magic_api * api, Uint8 r, Uint8 g, Uint8 b);
+int rainbow_requires_colors(magic_api * api, int which);
+void rainbow_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas);
+void rainbow_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas);
+int rainbow_modes(magic_api * api, int which);
+
+Uint32 rainbow_api_version(void) { return(TP_MAGIC_API_VERSION); }
+
 // Load our sfx:
 int rainbow_init(magic_api * api)
 {
@@ -82,16 +116,14 @@ int rainbow_init(magic_api * api)
   return(1);
 }
 
-Uint32 rainbow_api_version(void) { return(TP_MAGIC_API_VERSION); }
-
 // We have multiple tools:
-int rainbow_get_tool_count(magic_api * api)
+int rainbow_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
 {
   return(1);
 }
 
 // Load our icons:
-SDL_Surface * rainbow_get_icon(magic_api * api, int which)
+SDL_Surface * rainbow_get_icon(magic_api * api, int which ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -102,13 +134,13 @@ SDL_Surface * rainbow_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char * rainbow_get_name(magic_api * api, int which)
+char * rainbow_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return(strdup(gettext_noop("Rainbow")));
 }
 
 // Return our descriptions, localized:
-char * rainbow_get_description(magic_api * api, int which, int mode)
+char * rainbow_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return(strdup(
 	   gettext_noop("You can draw in rainbow colors!")));
@@ -116,8 +148,8 @@ char * rainbow_get_description(magic_api * api, int which, int mode)
 
 // Do the effect:
 
-static void rainbow_linecb(void * ptr, int which,
-		    SDL_Surface * canvas, SDL_Surface * last,
+static void rainbow_linecb(void * ptr, int which ATTRIBUTE_UNUSED,
+		    SDL_Surface * canvas, SDL_Surface * last ATTRIBUTE_UNUSED,
                     int x, int y)
 {
   magic_api * api = (magic_api *) ptr;
@@ -160,7 +192,7 @@ void rainbow_drag(magic_api * api, int which, SDL_Surface * canvas,
 }
 
 // Affect the canvas on click:
-void rainbow_click(magic_api * api, int which, int mode,
+void rainbow_click(magic_api * api, int which, int mode ATTRIBUTE_UNUSED,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y,
 		   SDL_Rect * update_rect)
@@ -168,40 +200,40 @@ void rainbow_click(magic_api * api, int which, int mode,
   rainbow_drag(api, which, canvas, last, x, y, x, y, update_rect);
 }
 
-void rainbow_release(magic_api * api, int which,
-	           SDL_Surface * canvas, SDL_Surface * last,
-	           int x, int y,
-		   SDL_Rect * update_rect)
+void rainbow_release(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+	           SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
+	           int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED,
+		   SDL_Rect * update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // Clean up
-void rainbow_shutdown(magic_api * api)
+void rainbow_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 {
   if (rainbow_snd != NULL)
     Mix_FreeChunk(rainbow_snd);
 }
 
 // Record the color from Tux Paint:
-void rainbow_set_color(magic_api * api, Uint8 r, Uint8 g, Uint8 b)
+void rainbow_set_color(magic_api * api ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED)
 {
 }
 
 // Use colors:
-int rainbow_requires_colors(magic_api * api, int which)
+int rainbow_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void rainbow_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+void rainbow_switchin(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void rainbow_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+void rainbow_switchout(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int rainbow_modes(magic_api * api, int which)
+int rainbow_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return(MODE_PAINT);
 }
