@@ -24,7 +24,7 @@
   (See COPYING.txt)
 
   Last updated: July 8, 2008
-  $Id: ripples.c,v 1.8 2008/07/10 20:26:40 wkendrick Exp $
+  $Id: ripples.c,v 1.10 2011/12/19 22:49:44 perepujal Exp $
 */
 
 #include <stdio.h>
@@ -41,6 +41,31 @@ static Mix_Chunk * ripples_snd;
 
 static int ripples_z, ripples_brite;
 
+Uint32 ripples_api_version(void);
+int ripples_init(magic_api * api);
+int ripples_get_tool_count(magic_api * api);
+SDL_Surface * ripples_get_icon(magic_api * api, int which);
+char * ripples_get_name(magic_api * api, int which);
+char * ripples_get_description(magic_api * api, int which, int mode);
+void ripples_drag(magic_api * api, int which, SDL_Surface * canvas,
+	          SDL_Surface * last, int ox, int oy, int x, int y,
+		  SDL_Rect * update_rect);
+static void ripples_linecb(void * ptr, int which,
+                    SDL_Surface * canvas, SDL_Surface * last,
+                    int x, int y);
+void ripples_click(magic_api * api, int which, int mode,
+	           SDL_Surface * canvas, SDL_Surface * last,
+	           int x, int y, SDL_Rect * update_rect);
+void ripples_release(magic_api * api, int which,
+	           SDL_Surface * canvas, SDL_Surface * last,
+	           int x, int y, SDL_Rect * update_rect);
+void ripples_shutdown(magic_api * api);
+void ripples_set_color(magic_api * api, Uint8 r, Uint8 g, Uint8 b);
+int ripples_requires_colors(magic_api * api, int which);
+void ripples_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas);
+void ripples_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas);
+int ripples_modes(magic_api * api, int which);
+
 Uint32 ripples_api_version(void) { return(TP_MAGIC_API_VERSION); }
 
 #define deg_cos(x) cos((x) * M_PI / 180.0)
@@ -59,13 +84,13 @@ int ripples_init(magic_api * api)
 }
 
 // We have multiple tools:
-int ripples_get_tool_count(magic_api * api)
+int ripples_get_tool_count(magic_api * api ATTRIBUTE_UNUSED)
 {
   return(1);
 }
 
 // Load our icons:
-SDL_Surface * ripples_get_icon(magic_api * api, int which)
+SDL_Surface * ripples_get_icon(magic_api * api, int which ATTRIBUTE_UNUSED)
 {
   char fname[1024];
 
@@ -76,25 +101,25 @@ SDL_Surface * ripples_get_icon(magic_api * api, int which)
 }
 
 // Return our names, localized:
-char * ripples_get_name(magic_api * api, int which)
+char * ripples_get_name(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return(strdup(gettext_noop("Ripples")));
 }
 
 // Return our descriptions, localized:
-char * ripples_get_description(magic_api * api, int which, int mode)
+char * ripples_get_description(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED)
 {
   return(strdup(gettext_noop("Click to make ripples appear over your picture.")));
 }
 
 // Affect the canvas on drag:
-void ripples_drag(magic_api * api, int which, SDL_Surface * canvas,
-	          SDL_Surface * last, int ox, int oy, int x, int y,
-		  SDL_Rect * update_rect)
+void ripples_drag(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED,
+	          SDL_Surface * last ATTRIBUTE_UNUSED, int ox ATTRIBUTE_UNUSED, int oy ATTRIBUTE_UNUSED, int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED,
+		  SDL_Rect * update_rect ATTRIBUTE_UNUSED)
 {
 }
 
-static void ripples_linecb(void * ptr, int which,
+static void ripples_linecb(void * ptr, int which ATTRIBUTE_UNUSED,
                     SDL_Surface * canvas, SDL_Surface * last,
                     int x, int y)
 {
@@ -113,7 +138,7 @@ static void ripples_linecb(void * ptr, int which,
 }
 
 // Affect the canvas on click:
-void ripples_click(magic_api * api, int which, int mode,
+void ripples_click(magic_api * api, int which, int mode ATTRIBUTE_UNUSED,
 	           SDL_Surface * canvas, SDL_Surface * last,
 	           int x, int y, SDL_Rect * update_rect)
 {
@@ -153,39 +178,39 @@ void ripples_click(magic_api * api, int which, int mode,
 }
 
 // Affect the canvas on release:
-void ripples_release(magic_api * api, int which,
-	           SDL_Surface * canvas, SDL_Surface * last,
-	           int x, int y, SDL_Rect * update_rect)
+void ripples_release(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED,
+	           SDL_Surface * canvas ATTRIBUTE_UNUSED, SDL_Surface * last ATTRIBUTE_UNUSED,
+	           int x ATTRIBUTE_UNUSED, int y ATTRIBUTE_UNUSED, SDL_Rect * update_rect ATTRIBUTE_UNUSED)
 {
 }
 
 // No setup happened:
-void ripples_shutdown(magic_api * api)
+void ripples_shutdown(magic_api * api ATTRIBUTE_UNUSED)
 {
   if (ripples_snd != NULL)
     Mix_FreeChunk(ripples_snd);
 }
 
 // Record the color from Tux Paint:
-void ripples_set_color(magic_api * api, Uint8 r, Uint8 g, Uint8 b)
+void ripples_set_color(magic_api * api ATTRIBUTE_UNUSED, Uint8 r ATTRIBUTE_UNUSED, Uint8 g ATTRIBUTE_UNUSED, Uint8 b ATTRIBUTE_UNUSED)
 {
 }
 
 // Use colors:
-int ripples_requires_colors(magic_api * api, int which)
+int ripples_requires_colors(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
   return 0;
 }
 
-void ripples_switchin(magic_api * api, int which, int mode, SDL_Surface * canvas)
+void ripples_switchin(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
 {
 }
 
-void ripples_switchout(magic_api * api, int which, int mode, SDL_Surface * canvas)
+void ripples_switchout(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED, int mode ATTRIBUTE_UNUSED, SDL_Surface * canvas ATTRIBUTE_UNUSED)
 {
 }
 
-int ripples_modes(magic_api * api, int which)
+int ripples_modes(magic_api * api ATTRIBUTE_UNUSED, int which ATTRIBUTE_UNUSED)
 {
-  return(MODE_PAINT);
+  return(MODE_ONECLICK);
 }
