@@ -19,7 +19,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id: dirwalk.c,v 1.16 2009/06/18 02:43:31 albert Exp $
+  $Id: dirwalk.c,v 1.18 2009/11/23 07:45:25 albert Exp $
 */
 
 #include <stdio.h>
@@ -68,7 +68,7 @@
 ///////////////// directory walking callers and callbacks //////////////////
 
 void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
-		       unsigned dirlen, tp_ftw_str * files, unsigned i, char * locale)
+		       unsigned dirlen, tp_ftw_str * files, unsigned i, const char *restrict const locale)
 {
   dirlen = dirlen;
 
@@ -107,8 +107,8 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
       char fname[512];
       TuxPaint_Font *font;
       snprintf(fname, sizeof fname, "%s/%s", dir, files[i].str);
-/* printf("Loading font: %s  (locale is: %s)\n", fname, (locale != NULL ? locale : "NULL")); */
-      if (locale != NULL && strstr(fname, "locale") != NULL && all_locale_fonts == 0)
+/* printf("Loading font: %s  (locale is: %s)\n", fname, (locale ? locale : "NULL")); */
+      if (locale && strstr(fname, "locale") && !all_locale_fonts)
       {
         char fname_check[512];
         /* We're (probably) loading from our locale fonts folder; ONLY load our locale's font */
@@ -254,15 +254,15 @@ int compare_ftw_str(const void *v1, const void *v2)
 {
   const char *restrict const s1 = ((tp_ftw_str *) v1)->str;
   const char *restrict const s2 = ((tp_ftw_str *) v2)->str;
-  return -strcmp(s1, s2);
+  return -strcmp(s1, s2); /* FIXME: Should we try strcasecmp, to group things together despite uppercase/lowercase in filenames (e.g., Jigsaw* vs jigsaw* Starters)??? -bjk 2009.10.11 */
 }
 
 void tp_ftw(SDL_Surface * screen, char *restrict const dir, unsigned dirlen,
 	    int rsrc, void (*fn) (SDL_Surface * screen,
 				  const char *restrict const dir,
 				  unsigned dirlen, tp_ftw_str * files,
-				  unsigned count, char * locale),
-            char * locale)
+				  unsigned count, const char *restrict const locale),
+            const char *restrict const locale)
 {
   DIR *d;
   unsigned num_file_names = 0;
