@@ -4,7 +4,7 @@
   For Tux Paint
   Language-related functions
 
-  Copyright (c) 2002-2009 by Bill Kendrick and others
+  Copyright (c) 2002-2012 by Bill Kendrick and others
   bill@newbreedsoftware.com
   http://www.tuxpaint.org/
 
@@ -23,9 +23,9 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   (See COPYING.txt)
 
-  $Id: i18n.h,v 1.34 2009/06/03 20:46:07 wkendrick Exp $
+  $Id: i18n.h,v 1.77 2014/08/04 23:08:07 perepujal Exp $
   
-  June 14, 2002 - January 23, 2009
+  June 14, 2002 - April 16, 2014
 */
 
 
@@ -33,21 +33,30 @@
 #define I18N_H
 
 #include <stdio.h>
-
+#include "compiler.h"
 
 /* Possible languages: */
 
 enum
 {
+  LANG_ACH,                     /* Acholi */
   LANG_AF,			/* Afrikaans */
+  LANG_AK,                      /* Akan */
+  LANG_AM,                      /* Amharic */
+  LANG_AN,                      /* Aragones */
   LANG_AR,			/* Arabic */
+  LANG_AS,                      /* Assamese */
   LANG_AST,			/* Asturian */
   LANG_AZ,			/* Azerbaijani */
   LANG_BE,			/* Belarusian */
   LANG_BG,			/* Bulgarian */
+  LANG_BM,			/* Bambara */
   LANG_BO,			/* Tibetan */
   LANG_BR,			/* Breton */
+  LANG_BS,                      /* Bosnian */
+  LANG_CA_VALENCIA,             /* Valencian */
   LANG_CA,			/* Catalan */
+  LANG_CGG,                     /* Kiga */
   LANG_CS,			/* Czech */
   LANG_CY,			/* Welsh */
   LANG_DA,			/* Danish */
@@ -59,10 +68,12 @@ enum
   LANG_EN_GB,			/* English (British) */
   LANG_EN_ZA,			/* English (South African) */
   LANG_EO,			/* Esperanto */
-  LANG_ES,			/* Spanish */
   LANG_ES_MX,			/* Spanish (Mexican) */
+  LANG_ES,			/* Spanish */
   LANG_ET,			/* Estonian */
   LANG_EU,			/* Basque */
+  LANG_FA,			/* Persian */
+  LANG_FF,                      /* Fulah */
   LANG_FI,			/* Finnish */
   LANG_FO,			/* Faroese */
   LANG_FR,			/* French */
@@ -75,37 +86,60 @@ enum
   LANG_HI,			/* Hindi */
   LANG_HR,			/* Croatian */
   LANG_HU,			/* Hungarian */
+  LANG_HY,			/* Armenian */
   LANG_I_KLINGON_ROMANIZED,	/* Klingon (Romanized) */
   LANG_ID,			/* Indonesian */
   LANG_IS,			/* Icelandic */
   LANG_IT,			/* Italian */
+  LANG_IU,                      /* Inuktitut */
   LANG_JA,			/* Japanese */
   LANG_KA,			/* Georgian */
+  LANG_KN,                      /* Kannada */
   LANG_KM,			/* Khmer */
+  LANG_KOK_ROMAN,               /* Konkani (Roman) */
+  LANG_KOK,                     /* Konkani (Devaganari) */
   LANG_KO,			/* Korean */
   LANG_KU,			/* Kurdish */
+  LANG_LB,                      /* Luxembourgish */
+  LANG_LG,                      /* Luganda */
   LANG_LT,			/* Lithuanian */
   LANG_LV,			/* Latvian */
+  LANG_MAI,                     /* Maithili */
+  LANG_ML,                      /* Malayalam */
   LANG_MK,			/* Macedonian */
+  LANG_MN,			/* Mongolian */
+  LANG_MNI_BENGALI,             /* Manipuri (Bengali script)*/
+  LANG_MNI_METEI_MAYEK,         /* Manipuri (Metei Mayek script) */
+  LANG_MR,                      /* Marath */
   LANG_MS,			/* Malay */
   LANG_NB,			/* Norwegian Bokmal */
+  LANG_NE,                      /* Nepali */
   LANG_NL,			/* Dutch */
   LANG_NN,			/* Norwegian Nynorsk */
   LANG_NR,                      /* Ndebele */
+  LANG_NSO,                     /* Northern Sotho */
   LANG_OC,			/* Occitan */
   LANG_OJ,			/* Ojibway */
+  LANG_OR,                      /* Odia */
+  LANG_PA,			/* Punjabi */
   LANG_PL,			/* Polish */
   LANG_PT_BR,			/* Portuguese (Brazilian) */
-  LANG_PT_PT,			/* Portuguese (Portugal) */
+  LANG_PT,			/* Portuguese */
   LANG_RO,			/* Romanian */
   LANG_RU,			/* Russian */
   LANG_RW,			/* Kinyarwanda */
+  LANG_SAT_OL_CHIKI,
+  LANG_SAT,                     /* Santali */
+  LANG_SA,                      /* Sanskrit */
   LANG_SHS,			/* Shuswap */
+  LANG_SI,                      /* Sinhala */
   LANG_SK,			/* Slovak */
   LANG_SL,			/* Slovenian */
   LANG_SON,                     /* Songhay */
   LANG_SQ,			/* Albanian */
-  LANG_SR,			/* Serbian */
+  LANG_SR_LATIN,		/* Serbian (latin) */
+  LANG_SR,			/* Serbian (cyrillic) */
+  LANG_SU,                      /* Sundanese */
   LANG_SV,			/* Swedish */
   LANG_SW,			/* Swahili */
   LANG_TA,			/* Tamil */
@@ -113,16 +147,18 @@ enum
   LANG_TH,			/* Thai */
   LANG_TL,			/* Tagalog */
   LANG_TR,			/* Turkish */
-  LANG_TWI,			/* Twi */
+  LANG_TW,			/* Twi */
   LANG_UK,			/* Ukrainian */
+  LANG_VEC,			/* Venetian */
   LANG_VE,			/* Venda */
   LANG_VI,			/* Vietnamese */
   LANG_WA,			/* Walloon */
-  LANF_WO,                      /* Wolof */
+  LANG_WO,                      /* Wolof */
   LANG_XH,			/* Xhosa */
+  LANG_ZAM,			/* Zapotec (Miahuatlan) */
   LANG_ZH_CN,			/* Chinese (Simplified) */
   LANG_ZH_TW,			/* Chinese (Traditional) */
-  LANG_ZAM,			/* Zapotec (Miahuatlan) */
+  LANG_ZU,                      /* Zulu */
   NUM_LANGS
 };
 
@@ -139,27 +175,31 @@ typedef struct language_to_locale_struct
 /* Globals: */
 
 extern const char *lang_prefixes[NUM_LANGS];
-extern int lang_use_own_font[];
-extern int lang_use_right_to_left[];
-extern char *langstr;
 extern int need_own_font;
 extern int need_right_to_left; // Right-justify
 extern int need_right_to_left_word; // Words need to be reversed, too! (e.g., Hebrew, but not Arabic)
 extern const char *lang_prefix, *short_lang_prefix;
-extern const language_to_locale_struct language_to_locale_array[];
+extern int num_wished_langs;
 
+typedef struct w_langs
+{
+  int langint;
+  int need_own_font;
+  int need_right_to_left;
+  int need_right_to_left_word;
+  int lang_y_nudge;
+  const char *lang_prefix;
+  const char *short_lang_prefix;
+} w_langs;
 
+extern w_langs wished_langs[255];
 
 /* Function prototypes: */
 
-void set_langstr(const char *s);
-int set_current_language(void);
 int get_current_language(void);
-void show_lang_usage(FILE * f, const char *const prg);
-void show_locale_usage(FILE * f, const char *const prg);
-void setup_language(const char *const prg, int * y_nudge);
-void do_locale_option(const char *const arg);
-void ctype_utf8(void);
-
+int setup_i18n(const char *restrict lang, const char *restrict locale) MUST_CHECK;
+#ifdef NO_SDLPANGO
+int smash_i18n(void) MUST_CHECK;
+#endif
 
 #endif
