@@ -3,8 +3,9 @@
 //  Tux Paint
 //
 //  Created by Darrell Walisser on Sat Mar 15 2003.
-//  Copyright (c) 2003 Darrell Walisser. All rights reserved.
-//  $Id: macosx_print.h,v 1.5 2007/06/12 05:29:25 mfuhrer Exp $
+//  Modified by Martin Fuhrer 2007.
+//  Copyright (c) 2007 Darrell Walisser, Martin Fuhrer. All rights reserved.
+//  $Id: macosx_print.h,v 1.7 2008/01/04 05:39:16 mfuhrer Exp $
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,19 +25,17 @@
 
 #include "SDL.h"
 
-const char *SurfacePrint(SDL_Surface * surface, int showDialog);
+const char *SurfacePrint(SDL_Surface *surface, int showDialog);
+int DisplayPageSetup(const SDL_Surface *surface);
 
 #ifdef OBJECTIVEC
 
-BOOL DisplayPageSetup();
-
 @interface PrintSheetController : NSObject
 {
 	bool displayPrintSetupSheet;
 	bool displayPrintSheet;
 }
-
-- 
+-
 @end
 
 #endif OBJECTIVEC
