@@ -48,12 +48,12 @@ enum
 /* Tux filenames: */
 
 const char *const tux_img_fnames[NUM_TIP_TUX] = {
-  DATA_PREFIX "images/tux/default.png",
-  DATA_PREFIX "images/tux/kiss.png",
-  DATA_PREFIX "images/tux/bored.png",
-  DATA_PREFIX "images/tux/great.png",
-  DATA_PREFIX "images/tux/oops.png",
-  DATA_PREFIX "images/tux/wait.png"
+  "images/tux/default.png",
+  "images/tux/kiss.png",
+  "images/tux/bored.png",
+  "images/tux/great.png",
+  "images/tux/oops.png",
+  "images/tux/wait.png"
 };
 
 #endif /* TIP_TUX_H */
